@@ -1,5 +1,5 @@
 package XML::CompareML::Base;
-$XML::CompareML::Base::VERSION = '0.2.12';
+$XML::CompareML::Base::VERSION = '0.2.13';
 use strict;
 use warnings;
 
@@ -69,7 +69,7 @@ sub _get_implementations
             +{
                 'id'   => $_->getAttribute("id"),
                 'name' => $self->_impl_get_name($_)
-                }
+            }
         } $self->_findnodes("/comparison/meta/implementations/impl")
     ];
 }
@@ -84,7 +84,7 @@ sub _get_timestamp
     }
     else
     {
-        return undef;
+        return;
     }
 }
 
@@ -134,7 +134,7 @@ sub process
     $self->impls_indexes(
         +{ map { $impls[$_]->{'id'} => $_ } ( 0 .. $#impls ) } );
     $self->impls_names( +{ map { $_->{'id'} => $_->{'name'} } @impls } );
-    $self->_timestamp( $self->_get_timestamp() );
+    $self->_timestamp( scalar( $self->_get_timestamp() ) );
 
     $self->{document_text} = "";
     $self->{toc_text}      = "";
@@ -259,16 +259,12 @@ XML::CompareML::Base - base class for the CompareML-to-something converters.
 
 =head1 VERSION
 
-version 0.2.12
+version 0.2.13
 
 =head1 SYNOPSIS
 
 see L<XML::CompareML>.
 
-=head1 VERSION
-
-version 0.2.12
-
 =head1 METHODS
 
 =head2 new()
@@ -294,37 +290,10 @@ Copyright 2004, Shlomi Fish. All rights reserved.
 You can use, modify and distribute this module under the terms of the MIT X11
 license. ( L<http://www.opensource.org/licenses/mit-license.php> ).
 
-=head1 AUTHOR
-
-Shlomi Fish <shlomif@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is Copyright (c) 2018 by Shlomi Fish.
-
-This is free software, licensed under:
-
-  The MIT (X11) License
-
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website
-L<https://github.com/shlomif/xml-compareml/issues>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
-=head2 Perldoc
-
-You can find documentation for this module with the perldoc command.
-
-  perldoc XML::CompareML::Base
-
 =head2 Websites
 
 The following websites have more information about this module, and may be of help to you. As always,
@@ -342,14 +311,6 @@ L<https://metacpan.org/release/XML-CompareML>
 
 =item *
 
-Search CPAN
-
-The default CPAN search engine, useful to view POD in HTML format.
-
-L<http://search.cpan.org/dist/XML-CompareML>
-
-=item *
-
 RT: CPAN's Bug Tracker
 
 The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
@@ -358,22 +319,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=XML-CompareML>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/XML-CompareML>
-
-=item *
-
-CPAN Ratings
-
-The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
-
-L<http://cpanratings.perl.org/d/XML-CompareML>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
@@ -422,4 +367,25 @@ L<https://github.com/shlomif/xml-compareml>
 
   git clone git://github.com/shlomif/xml-compareml.git
 
+=head1 AUTHOR
+
+Shlomi Fish <shlomif@cpan.org>
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+L<https://github.com/shlomif/xml-compareml/issues>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2018 by Shlomi Fish.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
 =cut
